@@ -1,7 +1,7 @@
 package Filename::Backup;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-10-19'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,11 +14,16 @@ our @EXPORT_OK = qw(check_backup_filename);
 our %SPEC;
 
 our %SUFFIXES = (
-    '~'    => 1,
-    '.bak' => 1,
-    '.old' => 1,
+    '~'     => 1,
+    '.bak'  => 1,
+    '.old'  => 1,
+    '.orig' => 1, # patch
+    '.rej'  => 1, # patch
+    '.swp'  => 1,
     # XXX % (from /etc/mime.types)
     # XXX sik? (from /etc/mime.types)
+    # XXX .dpkg*
+    # XXX .rpm*
 );
 
 $SPEC{check_backup_filename} = {
@@ -59,6 +64,12 @@ sub check_backup_filename {
     my %args = @_;
 
     my $filename = $args{filename};
+    my $orig_filename;
+
+    if ($filename =~ /\A#(.+)#\z/) {
+        $orig_filename = $1;
+        goto RETURN;
+    }
 
     $filename =~ /(~|\.\w+)\z/ or return 0;
     my $ci = $args{ci} // 1;
@@ -79,8 +90,9 @@ sub check_backup_filename {
     }
     return 0 unless $spec;
 
-    (my $orig_filename = $filename) =~ s/\Q$suffix\E\z//;
+    ($orig_filename = $filename) =~ s/\Q$suffix\E\z//;
 
+  RETURN:
     return {
         original_filename => $orig_filename,
     };
@@ -101,7 +113,7 @@ Filename::Backup - Check whether filename indicates being a backup file
 
 =head1 VERSION
 
-This document describes version 0.02 of Filename::Backup (from Perl distribution Filename-Backup), released on 2015-09-03.
+This document describes version 0.03 of Filename::Backup (from Perl distribution Filename-Backup), released on 2016-10-19.
 
 =head1 SYNOPSIS
 
@@ -123,6 +135,8 @@ This document describes version 0.02 of Filename::Backup (from Perl distribution
 
 Check whether filename indicates being a backup file.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -144,12 +158,6 @@ information returned, e.g. editor name (if filename indicates backup from
 certain backup program), date (if filename contains date information), and so
 on.
 
-=head1 SEE ALSO
-
-L<Filename::Archive>
-
-L<Filename::Compressed>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Filename-Backup>.
@@ -166,13 +174,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Filename::Archive>
+
+L<Filename::Compressed>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
